==> ep-framework-gath-1.0.10-603399.tar: src/Plugin/Brands.php <==
<?php
namespace Ep\Gath\Plugin;

/**
 * Class Brands
 *
 * @package Ep\Gath\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/woocommerce
 */
class Brands extends AbstractGathPlugin
{
    protected $brandsById = [];

    public function __invoke(): void
    {
        add_filter('get_terms', [$this, 'get_terms'], 10, 3);
        add_filter('woocommerce_get_filtered_term_product_counts_query', [$this, 'wc_get_filtered_term_product_counts_query']);
    }

    public function get_terms($terms, $taxonomy, $query_vars): array
    {
        if ($taxonomy === 'product_brand' || (count($taxonomy) === 1 && in_array('product_brand', $taxonomy))) {
            if (isset($query_vars['category'])) {
                $genericArticleIds = get_term_meta($query_vars['category'], 'genericArticleIds', true);

                if (!$genericArticleIds) {
                    $data = $this->gath->getBrandsByCategory($query_vars['category']);
                }
            } else {
                $data = $this->gath->getBrands();
            }

            $terms = $this->loadBrands($data['Results']);
            if ($query_vars['fields'] === 'ids') {
                $terms = array_map(function($term) { return $term->term_id; }, $terms);
            }
        }

        return $terms;
    }

    public function wc_get_filtered_term_product_counts_query($query)
    {
        $query['select'] = 'SELECT 1 AS term_count, terms.term_id AS term_count_id';
        $query['join'] = '';

        preg_match('/terms\.term_id\s+IN\s+\(([0-9, ]+)\)/', $query['where'], $matches);
        $ids = array_map('intval', array_map('trim', explode(',', $matches[1])));

        $subtable = [];
        foreach ($ids as $id) {
            $subtable[] = 'SELECT ' . $id . ' AS term_id';
        }

        $query['from'] = 'FROM (' . implode(' UNION ', $subtable) . ') AS terms';

        $query['where'] = 'WHERE terms.term_id IN(' . $matches[1] . ')';
        $query['group_by'] = '';

        return $query;
    }


    protected function loadBrands(array $brands)
    {
        $loaded = [];

        foreach ($brands as $brand) {
            $this->brandsById[$brand['id']] = $brand;
            $loaded[] = $this->loadBrand($brand);
        }

        return $loaded;
    }

    protected function loadBrand(array $brand)
    {
        return new \WP_Term((object) [
            'term_id' => $brand['id'],
            'name' => $brand['name'],
            'image' => rtrim($this->gath->getImageBaseUri(), '/') . ltrim($brand['image'], '/'),
        ]);
    }
}

==> ep-framework-gath-2.1.15-0a7201.tar: src/Plugin/Brands.php <==
<?php
namespace Ep\Gath\Plugin;

/**
 * Class Brands
 *
 * @package Ep\Gath\Plugin
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/woocommerce
 */
class Brands extends AbstractGathPlugin
{
    protected $brandsById = [];

    public function attach(): void
    {
        add_filter('get_terms', [$this, 'get_terms'], 10, 3);
        add_filter('woocommerce_get_filtered_term_product_counts_query', [$this, 'wc_get_filtered_term_product_counts_query']);
    }

    public function get_terms($terms, $taxonomy, $query_vars): array
    {
        $data = [];

        if ($taxonomy === 'product_brand' || (count($taxonomy) === 1 && in_array('product_brand', $taxonomy))) {
            if (isset($query_vars['category'])) {
                $genericArticleIds = get_term_meta($query_vars['category'], 'genericArticleIds', true);

                if (!$genericArticleIds) {
                    $data = $this->gath->getBrandsByCategory($query_vars['category']);
                }
            } else {
                $data = $this->gath->getBrands();
            }

            if (is_array($data) && isset($data['Results']) && is_array($data['Results'])) {
                $terms = $this->loadBrands($data['Results']);

                if ($query_vars['fields'] === 'ids') {
                    $terms = array_map(function($term) { return $term->term_id; }, $terms);
                }
            }
        }

        return $terms;
    }

    public function wc_get_filtered_term_product_counts_query($query)
    {
        $query['select'] = 'SELECT 1 AS term_count, terms.term_id AS term_count_id';
        $query['join'] = '';

        preg_match('/terms\.term_id\s+IN\s+\(([0-9, ]+)\)/', $query['where'], $matches);
        $ids = array_map('intval', array_map('trim', explode(',', $matches[1])));

        $subtable = [];
        foreach ($ids as $id) {
            $subtable[] = 'SELECT ' . $id . ' AS term_id';
        }

        $query['from'] = 'FROM (' . implode(' UNION ', $subtable) . ') AS terms';

        $query['where'] = 'WHERE terms.term_id IN(' . $matches[1] . ')';
        $query['group_by'] = '';

        return $query;
    }


    protected function loadBrands(array $brands)
    {
        $loaded = [];

        foreach ($brands as $brand) {
            if (!$brand) {
                continue;
            }

            $this->brandsById[$brand['id']] = $brand;
            $loaded[] = $this->loadBrand($brand);
        }

        return $loaded;
    }

    protected function loadBrand(array $brand)
    {
        $brandImage = $brand['image'] ?? '';

        return new \WP_Term((object) [
            'term_id' => $brand['id'],
            'name' => $brand['name'],
            'image' => rtrim($this->gath->getImageBaseUri(), '/') . '/' . ltrim($brandImage, '/'),
        ]);
    }
}
